@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.cc,v 1.145 2008/11/27 05:56:09 lav Exp $ */
+/* $Id: CmdExec.cc,v 1.146.2.1 2009/07/21 09:30:26 lav Exp $ */
 
 #include <config.h>
 #include <stddef.h>
@@ -127,8 +127,8 @@ int CmdExec::find_cmd(const char *cmd_name,const struct cmd_rec **ret)
 {
    int part=0;
    const cmd_rec *c=dyn_cmd_table?dyn_cmd_table.get():static_cmd_table;
-   const int count=dyn_cmd_table?dyn_cmd_table.count():1024;
-   for(int i=0; i<count && c->name; i++,c++)
+   const int count=dyn_cmd_table?dyn_cmd_table.count():static_cmd_table_length;
+   for(int i=0; i<count; i++,c++)
    {
       if(!strcasecmp(c->name,cmd_name))
       {
@@ -1153,31 +1153,29 @@ void CmdExec::skip_cmd(int len)
       free_used_aliases();
 }
 
+int CmdExec::cmd_rec::cmp(const CmdExec::cmd_rec *a,const CmdExec::cmd_rec *b)
+{
+   return strcmp(a->name,b->name);
+}
+
 xarray<CmdExec::cmd_rec> CmdExec::dyn_cmd_table;
 void CmdExec::RegisterCommand(const char *name,cmd_creator_t creator,const char *short_desc,const char *long_desc)
 {
    if(dyn_cmd_table==0)
-   {
-      int count=0;
-      for(const cmd_rec *c=static_cmd_table; c->name; c++)
-        count++;
-      dyn_cmd_table.nset(static_cmd_table,count);
-   }
-   for(int i=0; i<dyn_cmd_table.count(); i++)
+      dyn_cmd_table.nset(static_cmd_table,static_cmd_table_length);
+   cmd_rec new_entry={name,creator,short_desc,long_desc};
+   int i;
+   if(dyn_cmd_table.bsearch(new_entry,cmd_rec::cmp,&i))
    {
       cmd_rec *const c=&dyn_cmd_table[i];
-      if(!strcmp(c->name,name))
-      {
-	 c->creator=creator;
-	 if(short_desc)
-	    c->short_desc=short_desc;
-	 if(long_desc)
-	    c->long_desc=long_desc;
-	 return;
-      }
+      c->creator=creator;
+      if(short_desc)
+	 c->short_desc=short_desc;
+      if(long_desc)
+	 c->long_desc=long_desc;
+      return;
    }
-   cmd_rec new_entry={name,creator,short_desc,long_desc};
-   dyn_cmd_table.append(new_entry);
+   dyn_cmd_table.insert(new_entry,i);
 }
 
 void CmdExec::ChangeSession(FileAccess *new_session)
