@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.h,v 1.68 2008/11/27 05:56:09 lav Exp $ */
+/* $Id: CmdExec.h,v 1.69.2.1 2009/07/21 09:30:26 lav Exp $ */
 
 #ifndef CMDEXEC_H
 #define CMDEXEC_H
@@ -93,8 +93,11 @@ private:
       cmd_creator_t creator;
       const char  *short_desc;
       const char  *long_desc;
+
+      static int cmp(const CmdExec::cmd_rec *a,const CmdExec::cmd_rec *b);
    };
    static const cmd_rec static_cmd_table[];
+   static const int static_cmd_table_length;
    static xarray<cmd_rec> dyn_cmd_table;
 
    static int find_cmd(const char *cmd_name,const cmd_rec **ret);
