@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Speedometer.cc,v 1.21 2008/11/27 05:56:29 lav Exp $ */
+/* $Id: Speedometer.cc,v 1.23 2009/03/20 10:23:40 lav Exp $ */
 
 #include <config.h>
 #include <math.h>
@@ -31,9 +31,6 @@
 #undef super
 #define super SMTask
 
-char Speedometer::buf_rate[40];
-char Speedometer::buf_eta[40];
-
 Speedometer::Speedometer(const char *p)
 {
    period=15;
@@ -92,142 +89,58 @@ void Speedometer::Add(int b)
    if(rate<0)
       rate=0;
 }
-const char *Speedometer::GetStr(float r)
+xstring& Speedometer::GetStr(float r)
 {
-   buf_rate[0]=0;
    if(r<1)
-      return "";
+      return xstring::get_tmp("");
    if(r<1024)
       // for translator: those are the units. This is 'byte per second'
-      sprintf(buf_rate,_("%.0fb/s"),r);
+      return xstring::format(_("%.0fb/s"),r);
    else if(r<1024*1024)
       // for translator: This is 'kilobyte per second'
-      sprintf(buf_rate,_("%.1fK/s"),r/1024.);
+      return xstring::format(_("%.1fK/s"),r/1024.);
    else
       // for translator: This is 'Megabyte per second'
-      sprintf(buf_rate,_("%.2fM/s"),r/1024./1024.);
-   return buf_rate;
+      return xstring::format(_("%.2fM/s"),r/(1024.*1024));
 }
-const char *Speedometer::GetETAStrFromSize(off_t size)
+xstring& Speedometer::GetETAStrFromSize(off_t size)
 {
-   buf_eta[0]=0;
-
    if(!Valid() || Get()<1)
-      return buf_eta;
-
+      return xstring::get_tmp("");
    return GetETAStrFromTime(long(size/rate+.5));
 }
-const char *Speedometer::GetETAStrFromTime(long eta)
+xstring& Speedometer::GetETAStrFromTime(long eta)
 {
-   buf_eta[0]=0;
-
    if(eta<0)
-      return buf_eta;
+      return xstring::get_tmp("");
 
-   long eta2=0;
-   long ueta=0;
-   long ueta2=0;
-   const char *letter=0;
-   const char *letter2=0;
-
-   // for translator: only first letter matters
-   const char *day_c=_("day");
-   const char *hour_c=_("hour");
-   const char *minute_c=_("minute");
-   const char *second_c=_("second");
+   unsigned flags=TimeInterval::TO_STR_TRANSLATE;
+   if(terse)
+      flags+=TimeInterval::TO_STR_TERSE;
 
    // for translator: Estimated Time of Arrival.
-   const char *tr_eta=_("eta:");
-
-   if(terse)
-   {
-      if(eta>=100*HOUR)
-      {
-	 ueta=(eta+DAY/2)/DAY;
-	 eta2=eta-ueta*DAY;
-	 letter=day_c;
-	 if(ueta<10)
-	 {
-	    letter2=hour_c;
-	    ueta2=((eta2<-HOUR/2?eta2+DAY:eta2)+HOUR/2)/HOUR;
-	    if(ueta2>0 && eta2<-HOUR/2)
-	       ueta--;
-	 }
-      }
-      else if(eta>=100*MINUTE)
-      {
-	 ueta=(eta+HOUR/2)/HOUR;
-	 eta2=eta-ueta*HOUR;
-	 letter=hour_c;
-	 if(ueta<10)
-	 {
-	    letter2=minute_c;
-	    ueta2=((eta2<-MINUTE/2?eta2+HOUR:eta2)+MINUTE/2)/MINUTE;
-	    if(ueta2>0 && eta2<-MINUTE/2)
-	       ueta--;
-	 }
-      }
-      else if(eta>=100)
-      {
-	 ueta=(eta+MINUTE/2)/MINUTE;
-	 letter=minute_c;
-      }
-      else
-      {
-	 ueta=eta;
-	 letter=second_c;
-      }
-      if(letter2 && ueta2>0)
-	 sprintf(buf_eta,"%s%ld%.*s%ld%.*s",tr_eta,ueta,mblen(letter,strlen(letter)),letter,
-						   ueta2,mblen(letter2,strlen(letter2)),letter2);
-      else
-	 sprintf(buf_eta,"%s%ld%.*s",tr_eta,ueta,mblen(letter,strlen(letter)),letter);
-   }
-   else // verbose eta (by Ben Winslow)
-   {
-      long unit;
-      strcpy(buf_eta, tr_eta);
-
-      if(eta>=DAY)
-      {
-	 unit=eta/DAY;
-	 sprintf(buf_eta+strlen(buf_eta),"%ld%.*s",unit,mblen(day_c,strlen(day_c)),day_c);
-      }
-      if(eta>=HOUR)
-      {
-	 unit=(eta/HOUR)%24;
-	 sprintf(buf_eta+strlen(buf_eta),"%ld%.*s",unit,mblen(hour_c,strlen(hour_c)),hour_c);
-      }
-      if(eta>=MINUTE)
-      {
-	 unit=(eta/MINUTE)%60;
-	 sprintf(buf_eta+strlen(buf_eta),"%ld%.*s",unit,mblen(minute_c,strlen(minute_c)),minute_c);
-      }
-      unit=eta%60;
-      sprintf(buf_eta+strlen(buf_eta), "%ld%.*s",unit,mblen(second_c,strlen(second_c)),second_c);
-   }
-   return buf_eta;
+   return xstring::cat(_("eta:"),TimeInterval(eta,0).toString(flags),NULL);
 }
 const char *Speedometer::GetStrS(float r)
 {
-   GetStr(r);
-   if(buf_rate[0])
-      strcat(buf_rate," ");
-   return buf_rate;
+   xstring &rate=GetStr(r);
+   if(rate.length())
+      rate.append(' ');
+   return rate;
 }
 const char *Speedometer::GetETAStrSFromSize(off_t s)
 {
-   GetETAStrFromSize(s);
-   if(buf_eta[0])
-      strcat(buf_eta," ");
-   return buf_eta;
+   xstring &eta=GetETAStrFromSize(s);
+   if(eta.length())
+      eta.append(' ');
+   return eta;
 }
 const char *Speedometer::GetETAStrSFromTime(long s)
 {
-   GetETAStrFromTime(s);
-   if(buf_eta[0])
-      strcat(buf_eta," ");
-   return buf_eta;
+   xstring &eta=GetETAStrFromTime(s);
+   if(eta.length())
+      eta.append(' ');
+   return eta;
 }
 void Speedometer::Reset()
 {
