@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.292 2009/01/16 08:41:03 lav Exp $ */
+/* $Id: commands.cc,v 1.294.2.1 2009/07/21 09:30:26 lav Exp $ */
 
 #include <config.h>
 
@@ -476,9 +476,8 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 N_("Same as more, but filter each file through bzcat\n")},
 
    {".tasks",  cmd_tasks,  0,0},
-
-   {NULL,NULL}
 };
+const int CmdExec::static_cmd_table_length=sizeof(static_cmd_table)/sizeof(static_cmd_table[0]);
 
 #define charcasecmp(a,b) (tolower((unsigned char)(a))-tolower((unsigned char)(b)))
 // returns:
@@ -684,7 +683,7 @@ Job *CmdExec::builtin_exit()
       detach=true;
    if(kill)
       Job::KillAll();
-   else if(detach)
+   if(detach)
       exec->Exit(code);
    else {
       int loc=0;
@@ -1260,7 +1259,7 @@ Job *CmdExec::builtin_queue()
 
 	 if(!arg)
 	    queue->queue_feeder->DelJob(-1, verbose); /* delete the last job */
-	 else if(isdigit(arg[0]) && atoi(arg) != 0)
+	 else if(atoi(arg) != 0)
 	    queue->queue_feeder->DelJob(atoi(arg)-1, verbose);
 	 else
 	    queue->queue_feeder->DelJob(arg, verbose);
@@ -1275,7 +1274,7 @@ Job *CmdExec::builtin_queue()
 	  * queue -m "*get*" 1
 	  * queue -m 3    (move entry 3 to the end) */
          const char *a1 = args->getarg(args->getindex());
-	 if(a1 && !isdigit(a1[0])) {
+	 if(a1 && !isdigit((unsigned char)a1[0])) {
 	    eprintf(_("%s: -m: Number expected as second argument. "), args->a0());
 	    goto err;
 	 }
@@ -1288,7 +1287,7 @@ Job *CmdExec::builtin_queue()
 	    break;
 	 }
 
-	 if(isdigit(arg[0]) && atoi(arg) != 0) {
+	 if(atoi(arg) != 0) {
 	    queue->queue_feeder->MoveJob(atoi(arg)-1, to, verbose);
 	    break;
 	 }
@@ -1514,9 +1513,9 @@ const char *FileSetOutput::parse_argv(const Ref<ArgV>& a)
 	 human_opts=human_autoscale|human_SI;
 	 break;
       case OPT_BLOCK_SIZE:
-	 if(!isdigit(optarg[0]))
-	    return _("invalid block size");
 	 output_block_size = atoi(optarg);
+	 if(output_block_size == 0)
+	    return _("invalid block size");
 	 break;
       case('1'):
 	 single_column = true;
@@ -2524,26 +2523,25 @@ void CmdExec::print_cmd_help(const char *cmd)
 void CmdExec::print_cmd_index()
 {
    int i=0;
-   const char *c1;
    const cmd_rec *cmd_table=dyn_cmd_table?dyn_cmd_table.get():static_cmd_table;
-   const int count=dyn_cmd_table?dyn_cmd_table.count():1024;
-   while(i<count && cmd_table[i].name)
+   const int count=dyn_cmd_table?dyn_cmd_table.count():static_cmd_table_length;
+   while(i<count)
    {
-      while(cmd_table[i].name && !cmd_table[i].short_desc)
+      while(i<count && !cmd_table[i].short_desc)
 	 i++;
-      if(!cmd_table[i].name)
+      if(i>=count)
 	 break;
-      c1=cmd_table[i].short_desc;
+      const char *c1=gettext(cmd_table[i].short_desc);
       i++;
-      while(cmd_table[i].name && !cmd_table[i].short_desc)
+      while(i<count && !cmd_table[i].short_desc)
 	 i++;
-      if(cmd_table[i].name)
+      if(i<count)
       {
-	 printf("\t%-35s %s\n",gettext(c1),gettext(cmd_table[i].short_desc));
+	 printf("\t%-35s %s\n",c1,gettext(cmd_table[i].short_desc));
 	 i++;
       }
       else
-	 printf("\t%s\n",_(c1));
+	 printf("\t%s\n",c1);
    }
 }
 
@@ -2961,12 +2959,12 @@ CMD(du)
 	 separate_dirs = true;
 	 break;
       case OPT_BLOCK_SIZE:
-	 if(!isdigit(optarg[0]) || atoi(optarg) == 0)
+	 blocksize = atoi(optarg);
+	 if(blocksize == 0)
 	 {
 	    eprintf(_("%s: invalid block size `%s'\n"),op,optarg);
 	    return 0;
 	 }
-	 blocksize = atoi(optarg);
 	 break;
       case OPT_EXCLUDE:
 	 exclude=optarg;
