@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: parsecmd.cc,v 1.14 2007/10/24 14:38:49 lav Exp $ */
+/* $Id: parsecmd.cc,v 1.16 2008/11/27 05:56:43 lav Exp $ */
 
 #include <config.h>
 #include <fcntl.h>
@@ -52,12 +52,7 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
    else
       args=new ArgV;
 
-   if(output)
-   {
-      delete output;
-      output=0;
-   }
-
+   output=0;
    char redir_type=0;
    background=0;
 
