@@ -345,6 +345,7 @@ char *ParsedURL::Combine(const char *home,bool use_rfc1738)
    return u.borrow();
 }
 
+// decode in place, return the new string length
 int url::decode_string(char *str)
 {
    char *p=str;
@@ -353,7 +354,7 @@ int url::decode_string(char *str)
    char *o=p;
    while(*p)
    {
-      if(*p=='%' && isxdigit(p[1]) && isxdigit(p[2]))
+      if(*p=='%' && isxdigit((unsigned char)p[1]) && isxdigit((unsigned char)p[2]))
       {
 	 int n;
 	 if(sscanf(p+1,"%2x",&n)==1)
@@ -366,18 +367,17 @@ int url::decode_string(char *str)
       *o++=*p++;
    }
    *o=0;
-   return p-str;
+   return o-str;
 }
 
 const char *url::decode(const char *p)
 {
    if(!p)
       return 0;
-   static xstring s("");
-   s.truncate(0);
+   xstring& s=xstring::get_tmp("");
    while(*p)
    {
-      if(*p=='%' && isxdigit(p[1]) && isxdigit(p[2]))
+      if(*p=='%' && isxdigit((unsigned char)p[1]) && isxdigit((unsigned char)p[2]))
       {
 	 int n;
 	 if(sscanf(p+1,"%2x",&n)==1)
@@ -425,12 +425,7 @@ const char *url::encode(const char *s,const char *unsafe)
    while((c=*s++))
    {
       if (need_quote(c))
-      {
-	 u.append('%');
-	 static const char h[]="0123456789ABCDEF";
-	 u.append(h[(c>>4)&15]);
-	 u.append(h[(c&15)]);
-      }
+	 u.appendf("%%%02X",(unsigned char)c);
       else
 	 u.append(c);
    }
